@@ -17,3 +17,10 @@ measures_to_codomain = function(measures) {
   names(domains) = ids(measures)
   Codomain$new(domains)
 }
+
+extract_runtime = function(resample_result) {
+  runtimes = map_dbl(get_private(resample_result)$.data$learner_states(get_private(resample_result)$.view), function(state) {
+    state$train_time + state$predict_time
+  })
+  sum(runtimes)
+}
