@@ -1,5 +1,6 @@
 #' @import data.table
 #' @import checkmate
+#' @import cli
 #' @import paradox
 #' @import mlr3misc
 #' @import mlr3
@@ -28,8 +29,9 @@
   x$add("mlr3fselect.svm_rfe", load_callback_svm_rfe)
   x$add("mlr3fselect.one_se_rule", load_callback_one_se_rule)
   x$add("mlr3fselect.internal_tuning", load_callback_internal_tuning)
+  x$add("mlr3fselect.async_freeze_archive", load_callback_freeze_archive)
 
-  assign("lg", lgr::get_logger("bbotk"), envir = parent.env(environment()))
+  assign("lg", lgr::get_logger("mlr3/bbotk"), envir = parent.env(environment()))
   if (Sys.getenv("IN_PKGDOWN") == "true") {
     lg$set_threshold("warn")
   }
